@@ -24,10 +24,11 @@
 #include <goffice/graph/gog-graph-impl.h>
 #include <goffice/graph/gog-chart-impl.h>
 #include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/data/go-data.h>
 #include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-styled-object.h>
 #include <goffice/utils/go-units.h>
 
 #include <gsf/gsf-impl-utils.h>
@@ -90,7 +91,7 @@ gog_graph_set_property (GObject *obj, guint param_id,
 		GObject *object = g_value_get_object (value);
 		if ((GODoc *) object == graph->doc)
 			break;
-		if (IS_GO_DOC (object)) {
+		if (GO_IS_DOC (object)) {
 			graph->doc = (GODoc *) object;
 			gog_object_document_changed (GOG_OBJECT (graph), graph->doc);
 		}
@@ -189,7 +190,7 @@ cb_force_theme (GtkButton *button, GogGraph *graph)
 
 static void
 gog_graph_populate_editor (GogObject *gobj, 
-			   GogEditor *editor, 
+			   GOEditor *editor, 
 			   G_GNUC_UNUSED GogDataAllocator *dalloc, 
 			   GOCmdContext *cc)
 {
@@ -198,7 +199,7 @@ gog_graph_populate_editor (GogObject *gobj,
 	GSList *theme_names;
 	static guint graph_pref_page = 0;
 
-	gui = go_libglade_new ("gog-graph-prefs.glade", "gog_graph_prefs", GETTEXT_PACKAGE, cc);
+	gui = go_glade_new ("gog-graph-prefs.glade", "gog_graph_prefs", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
@@ -233,12 +234,12 @@ gog_graph_populate_editor (GogObject *gobj,
 		box = glade_xml_get_widget (gui, "gog_graph_prefs");
 		g_object_set_data_full (G_OBJECT (box), "gui", gui,
 					(GDestroyNotify)g_object_unref);
-		gog_editor_add_page (editor, box, _("Theme"));
+		go_editor_add_page (editor, box, _("Theme"));
 
 		g_slist_free (theme_names);	
 	}	     
 
-	gog_editor_set_store_page (editor, &graph_pref_page);
+	go_editor_set_store_page (editor, &graph_pref_page);
 }
 #endif
 
@@ -304,6 +305,13 @@ gog_graph_class_init (GogGraphClass *klass)
 	
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
+	/**
+	 * GogGraph::add-data:
+	 * @graph: the object on which the signal is emitted
+	 * @data: The new #GOData being added to @graph
+	 *
+	 * The ::add-data signal is emitted BEFORE @data has been added.
+	 **/
 	gog_graph_signals [GRAPH_ADD_DATA] = g_signal_new ("add-data",
 		G_TYPE_FROM_CLASS (klass),
 		G_SIGNAL_RUN_LAST,
@@ -313,6 +321,13 @@ gog_graph_class_init (GogGraphClass *klass)
 		G_TYPE_NONE,
 		1, G_TYPE_OBJECT);
 
+	/**
+	 * GogGraph::remove-data:
+	 * @graph: the object on which the signal is emitted
+	 * @data: The new #GOData being removed to @graph
+	 *
+	 * The ::remove-data signal is emitted BEFORE @data has been removed.
+	 **/
 	gog_graph_signals [GRAPH_REMOVE_DATA] = g_signal_new ("remove-data",
 		G_TYPE_FROM_CLASS (klass),
 		G_SIGNAL_RUN_LAST,
@@ -326,7 +341,7 @@ gog_graph_class_init (GogGraphClass *klass)
 		g_param_spec_object ("theme", 
 			_("Theme"),
 			_("The theme for elements of the graph"),
-			GOG_THEME_TYPE, 
+			GOG_TYPE_THEME, 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_klass, GRAPH_PROP_THEME_NAME,
 		g_param_spec_string ("theme-name", 
@@ -350,7 +365,7 @@ gog_graph_class_init (GogGraphClass *klass)
 		g_param_spec_object ("document", 
 			_("Document"),
 			_("the document for this graph"),
-			GO_DOC_TYPE, 
+			GO_TYPE_DOC, 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 }
 
@@ -371,14 +386,14 @@ gog_graph_init (GogGraph *graph)
 	GOG_OBJECT (graph)->user_name = g_strdup (_("Graph"));
 	gog_theme_fillin_style (graph->theme,
 		gso->style, GOG_OBJECT (graph), 0, TRUE);
-	gog_styled_object_apply_theme (gso, gso->style);
+	go_styled_object_apply_theme (GO_STYLED_OBJECT (gso), gso->style);
 
 	graph->data_refs = g_hash_table_new (g_direct_hash, g_direct_equal);
 }
 
 GSF_CLASS (GogGraph, gog_graph,
 	   gog_graph_class_init, gog_graph_init,
-	   GOG_OUTLINED_OBJECT_TYPE)
+	   GOG_TYPE_OUTLINED_OBJECT)
 
 /**
  * gog_graph_validate_chart_layout :
@@ -397,7 +412,7 @@ gog_graph_validate_chart_layout (GogGraph *graph)
 	unsigned i, max_col, max_row;
 	gboolean changed = FALSE;
 
-	g_return_val_if_fail (IS_GOG_GRAPH (graph), FALSE);
+	g_return_val_if_fail (GOG_IS_GRAPH (graph), FALSE);
 
 	/* There won't be many of charts so we do the right thing */
 
@@ -461,14 +476,14 @@ gog_graph_validate_chart_layout (GogGraph *graph)
 unsigned
 gog_graph_num_cols (GogGraph const *graph)
 {
-	g_return_val_if_fail (IS_GOG_GRAPH (graph), 1);
+	g_return_val_if_fail (GOG_IS_GRAPH (graph), 1);
 	return graph->num_cols;
 }
 
 unsigned
 gog_graph_num_rows (GogGraph const *graph)
 {
-	g_return_val_if_fail (IS_GOG_GRAPH (graph), 1);
+	g_return_val_if_fail (GOG_IS_GRAPH (graph), 1);
 	return graph->num_rows;
 }
 
@@ -489,7 +504,7 @@ gog_graph_dup (GogGraph const *graph)
 GogTheme *
 gog_graph_get_theme (GogGraph const *graph)
 {
-	g_return_val_if_fail (IS_GOG_GRAPH (graph), NULL);
+	g_return_val_if_fail (GOG_IS_GRAPH (graph), NULL);
 	return graph->theme;
 }
 
@@ -501,17 +516,17 @@ apply_theme (GogObject *object, GogTheme const *theme, gboolean force_auto)
 	for (ptr = object->children; ptr !=  NULL; ptr = ptr->next)
 		apply_theme (ptr->data, theme, force_auto);		
 
-	if (IS_GOG_STYLED_OBJECT (object)) {
-		GogStyledObject *styled_object = (GogStyledObject *) object;
-		GogStyle *style;
+	if (GO_IS_STYLED_OBJECT (object)) {
+		GOStyledObject *styled_object = (GOStyledObject *) object;
+		GOStyle *style;
 
-		style = gog_styled_object_get_style (styled_object);
+		style = go_styled_object_get_style (styled_object);
 		if (force_auto) 
 			/* FIXME: Some style settings are not themed yet,
 			 * such as font or fill type. */
-			gog_style_force_auto (style);
-		gog_styled_object_apply_theme (styled_object, style);
-		gog_styled_object_style_changed (styled_object);
+			go_style_force_auto (style);
+		go_styled_object_apply_theme (styled_object, style);
+		go_styled_object_style_changed (styled_object);
 		gog_object_emit_changed (object, TRUE);
 	}
 }
@@ -519,8 +534,8 @@ apply_theme (GogObject *object, GogTheme const *theme, gboolean force_auto)
 void
 gog_graph_set_theme (GogGraph *graph, GogTheme *theme)
 {
-	g_return_if_fail (IS_GOG_GRAPH (graph));
-	g_return_if_fail (IS_GOG_THEME (theme));
+	g_return_if_fail (GOG_IS_GRAPH (graph));
+	g_return_if_fail (GOG_IS_THEME (theme));
 
 	graph->theme = theme;
 
@@ -537,7 +552,7 @@ gog_graph_set_theme (GogGraph *graph, GogTheme *theme)
 GSList *
 gog_graph_get_data (GogGraph const *graph)
 {
-	g_return_val_if_fail (IS_GOG_GRAPH (graph), NULL);
+	g_return_val_if_fail (GOG_IS_GRAPH (graph), NULL);
 	return graph->data;
 }
 
@@ -559,8 +574,8 @@ gog_graph_ref_data (GogGraph *graph, GOData *dat)
 	if (dat == NULL)
 		return NULL;
 
-	g_return_val_if_fail (IS_GOG_GRAPH (graph), dat);
-	g_return_val_if_fail (IS_GO_DATA (dat), dat);
+	g_return_val_if_fail (GOG_IS_GRAPH (graph), dat);
+	g_return_val_if_fail (GO_IS_DATA (dat), dat);
 
 	/* Does it already exist in the graph ? */
 	res = g_hash_table_lookup (graph->data_refs, dat);
@@ -606,14 +621,14 @@ gog_graph_unref_data (GogGraph *graph, GOData *dat)
 	if (dat == NULL)
 		return;
 
-	g_return_if_fail (IS_GO_DATA (dat));
+	g_return_if_fail (GO_IS_DATA (dat));
 
 	g_object_unref (dat);
 
 	if (graph == NULL)
 		return;
 
-	g_return_if_fail (IS_GOG_GRAPH (graph));
+	g_return_if_fail (GOG_IS_GRAPH (graph));
 
 	/* once we've been destroyed the list is gone */
 	if (graph->data == NULL)
@@ -659,7 +674,7 @@ gog_graph_request_update (GogGraph *graph)
 	if (G_OBJECT (graph)->ref_count <= 0)
 		return FALSE;
 
-	g_return_val_if_fail (IS_GOG_GRAPH (graph), FALSE);
+	g_return_val_if_fail (GOG_IS_GRAPH (graph), FALSE);
 
 	if (graph->idle_handler == 0) { /* higher priority than canvas */
 		graph->idle_handler = g_idle_add_full (G_PRIORITY_HIGH_IDLE,
@@ -696,7 +711,7 @@ gog_graph_force_update (GogGraph *graph)
 void
 gog_graph_get_size (GogGraph *graph, double *width, double *height)
 {
-	g_return_if_fail (IS_GOG_GRAPH (graph));
+	g_return_if_fail (GOG_IS_GRAPH (graph));
 
 	if (width != NULL)
 		*width = graph->width;
@@ -714,7 +729,7 @@ gog_graph_get_size (GogGraph *graph, double *width, double *height)
 void
 gog_graph_set_size (GogGraph *graph, double width, double height)
 {
-	g_return_if_fail (IS_GOG_GRAPH (graph));
+	g_return_if_fail (GOG_IS_GRAPH (graph));
 
 	if (width != graph->width || height != graph->height) {
 		graph->height = height;
@@ -750,9 +765,9 @@ typedef struct {
 	void (*selection_changed) (GogGraphView *view, GogObject *gobj);
 } GogGraphViewClass;
 
-#define GOG_GRAPH_VIEW_TYPE	(gog_graph_view_get_type ())
-#define GOG_GRAPH_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_GRAPH_VIEW_TYPE, GogGraphView))
-#define IS_GOG_GRAPH_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_GRAPH_VIEW_TYPE))
+#define GOG_TYPE_GRAPH_VIEW	(gog_graph_view_get_type ())
+#define GOG_GRAPH_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_GRAPH_VIEW, GogGraphView))
+#define GOG_IS_GRAPH_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_GRAPH_VIEW))
 
 enum {
 	GRAPH_VIEW_PROP_0,
@@ -851,7 +866,7 @@ gog_graph_view_class_init (GogGraphViewClass *gview_klass)
 		g_param_spec_object ("renderer", 
 			_("Renderer"),
 			_("the renderer for this view"),
-			GOG_RENDERER_TYPE, 
+			GOG_TYPE_RENDERER, 
 			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 	
 	gog_graph_view_signals [GRAPH_VIEW_SELECTION_CHANGED] = g_signal_new ("selection-changed",
@@ -877,7 +892,7 @@ gog_graph_view_init (GogGraphView *view)
 
 GSF_CLASS (GogGraphView, gog_graph_view,
 	   gog_graph_view_class_init, gog_graph_view_init,
-	   GOG_OUTLINED_VIEW_TYPE)
+	   GOG_TYPE_OUTLINED_VIEW)
 
 #ifdef GOFFICE_WITH_GTK
 static void
@@ -994,7 +1009,7 @@ gog_graph_view_handle_event (GogGraphView *view, GdkEvent *event,
 GogView *
 gog_graph_view_get_selection (GogGraphView *gview)
 {
-	g_return_val_if_fail (IS_GOG_GRAPH_VIEW (gview), NULL);
+	g_return_val_if_fail (GOG_IS_GRAPH_VIEW (gview), NULL);
 
 	return gview->selected_view;
 }
@@ -1012,8 +1027,8 @@ gog_graph_view_set_selection (GogGraphView *gview, GogObject *gobj)
 {
 	GogView *view;
 
-	g_return_if_fail (IS_GOG_GRAPH_VIEW (gview));
-	g_return_if_fail (IS_GOG_OBJECT (gobj));
+	g_return_if_fail (GOG_IS_GRAPH_VIEW (gview));
+	g_return_if_fail (GOG_IS_OBJECT (gobj));
 
 	if (gview->selected_object == gobj)
 		return;
@@ -1088,7 +1103,7 @@ gog_graph_export_image (GogGraph *graph, GOImageFormat format, GsfOutput *output
 	GogRenderer *renderer;
 	gboolean result;
 
-	g_return_val_if_fail (IS_GOG_GRAPH (graph), FALSE);
+	g_return_val_if_fail (GOG_IS_GRAPH (graph), FALSE);
 	g_return_val_if_fail (format != GO_IMAGE_FORMAT_UNKNOWN, FALSE);
 
 	renderer = gog_renderer_new (graph);
@@ -1112,7 +1127,7 @@ void gog_graph_render_to_cairo (GogGraph *graph, cairo_t *cairo, double w, doubl
 {
 	GogRenderer *renderer;
 
-	g_return_if_fail (IS_GOG_GRAPH (graph));
+	g_return_if_fail (GOG_IS_GRAPH (graph));
 
 	renderer = gog_renderer_new (graph);
 	gog_renderer_render_to_cairo (renderer, cairo, w, h);
