@@ -22,28 +22,24 @@
 
 #include <goffice/goffice-config.h>
 #include <goffice/graph/gog-axis.h>
+#include <goffice/graph/gog-chart.h>
 #include <goffice/graph/gog-data-set.h>
 #include <goffice/graph/gog-label.h>
 #include <goffice/graph/gog-outlined-object.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-reg-curve.h>
 #include <goffice/graph/gog-data-allocator.h>
 #include <goffice/data/go-data.h>
+#include <goffice/utils/go-persist.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
 #ifdef GOFFICE_WITH_GTK
 #include <goffice/gtk/goffice-gtk.h>
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktogglebutton.h>
 #endif
 
 static GType gog_text_view_get_type (void);
@@ -65,10 +61,10 @@ typedef struct {
 	char *(*get_str)    (GogText *text);
 } GogTextClass;
 
-#define GOG_TEXT_TYPE		(gog_text_get_type ())
-#define GOG_TEXT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TEXT_TYPE, GogText))
-#define IS_GOG_TEXT(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TEXT_TYPE))
-#define GOG_TEXT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TEXT_TYPE, GogTextClass))
+#define GOG_TYPE_TEXT		(gog_text_get_type ())
+#define GOG_TEXT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_TEXT, GogText))
+#define GOG_IS_TEXT(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_TEXT))
+#define GOG_TEXT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_TEXT, GogTextClass))
 
 static GType gog_text_get_type (void);
 
@@ -108,12 +104,12 @@ gog_text_get_property (GObject *obj, guint param_id,
 }
 
 static void
-gog_text_init_style (GogStyledObject *gso, GogStyle *style)
+gog_text_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogObject *parent;
 
-	style->interesting_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL | 
-		GOG_STYLE_FONT | GOG_STYLE_TEXT_LAYOUT;
+	style->interesting_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL | 
+		GO_STYLE_FONT | GO_STYLE_TEXT_LAYOUT;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
 		style, GOG_OBJECT (gso), 0, FALSE);
 	
@@ -121,10 +117,13 @@ gog_text_init_style (GogStyledObject *gso, GogStyle *style)
 	 * in GogTheme, but it's not possible without breaking graph persistence
 	 * compatibility */
 	parent = gog_object_get_parent (GOG_OBJECT (gso));
-	if (IS_GOG_AXIS (parent) &&
-	    gog_axis_get_atype (GOG_AXIS (parent)) == GOG_AXIS_Y &&
-	    style->text_layout.auto_angle) 
-		style->text_layout.angle = 90.0;
+	if (GOG_IS_AXIS (parent)) {
+		GogChart *chart = GOG_CHART (gog_object_get_parent (parent));
+		if (!gog_chart_is_3d (chart)
+		    && gog_axis_get_atype (GOG_AXIS (parent)) == GOG_AXIS_Y
+		    && style->text_layout.auto_angle)
+			style->text_layout.angle = 90.0;
+	}
 }
 
 static void
@@ -143,7 +142,7 @@ gog_text_class_init (GogTextClass *klass)
 			_("Allow markup"),
 			_("Support basic html-ish markup"),
 			TRUE, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	gog_klass->view_type		= gog_text_view_get_type ();
 	style_klass->init_style 	= gog_text_init_style;
@@ -160,7 +159,7 @@ gog_text_get_str (GogText *text)
 {
 	GogTextClass *klass;
 	
-	g_return_val_if_fail (IS_GOG_TEXT (text), NULL);
+	g_return_val_if_fail (GOG_IS_TEXT (text), NULL);
 	
        	klass = GOG_TEXT_GET_CLASS (text);
 
@@ -172,7 +171,7 @@ gog_text_get_str (GogText *text)
 
 GSF_CLASS_ABSTRACT (GogText, gog_text,
 		    gog_text_class_init, gog_text_init,
-		    GOG_OUTLINED_OBJECT_TYPE);
+		    GOG_TYPE_OUTLINED_OBJECT);
 
 /************************************************************************/
 
@@ -189,7 +188,7 @@ static GObjectClass *label_parent_klass;
 #ifdef GOFFICE_WITH_GTK
 static void
 gog_label_populate_editor (GogObject *gobj, 
-			   GogEditor *editor, 
+			   GOEditor *editor, 
 			   GogDataAllocator *dalloc, 
 			   GOCmdContext *cc)
 {
@@ -206,10 +205,10 @@ gog_label_populate_editor (GogObject *gobj,
 	gtk_container_add (GTK_CONTAINER (alignment), hbox);
 	gtk_widget_show_all (alignment);
 
-	gog_editor_add_page (editor, alignment, _("Data"));
+	go_editor_add_page (editor, alignment, _("Data"));
 	
 	(GOG_OBJECT_CLASS(label_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
-	gog_editor_set_store_page (editor, &label_pref_page);
+	go_editor_set_store_page (editor, &label_pref_page);
 }
 #endif
 
@@ -218,10 +217,10 @@ gog_label_get_str (GogText *text)
 {
 	GogLabel *label = GOG_LABEL (text);
 	
-	g_return_val_if_fail (IS_GOG_LABEL (label), NULL);
+	g_return_val_if_fail (GOG_IS_LABEL (label), NULL);
 
 	if (label->text.data != NULL)
-		return g_strdup (go_data_scalar_get_str (GO_DATA_SCALAR (label->text.data)));
+		return go_data_get_scalar_string (label->text.data);
 	
 	return NULL;
 }
@@ -277,8 +276,8 @@ gog_label_dataset_init (GogDatasetClass *iface)
 
 GSF_CLASS_FULL (GogLabel, gog_label,
 		NULL, NULL, gog_label_class_init, NULL,
-		NULL, GOG_TEXT_TYPE, 0,
-		GSF_INTERFACE (gog_label_dataset_init, GOG_DATASET_TYPE))
+		NULL, GOG_TYPE_TEXT, 0,
+		GSF_INTERFACE (gog_label_dataset_init, GOG_TYPE_DATASET))
 
 /************************************************************************/
 	
@@ -346,7 +345,7 @@ cb_text_visibility_changed (GtkToggleButton *button, GogObject *gobj)
 
 static void
 gog_reg_eqn_populate_editor (GogObject *gobj, 
-			     GogEditor *editor, 
+			     GOEditor *editor, 
 			     GogDataAllocator *dalloc, 
 			     GOCmdContext *cc)
 {
@@ -354,11 +353,11 @@ gog_reg_eqn_populate_editor (GogObject *gobj,
 	GladeXML *gui;
 	GogRegEqn *reg_eqn = GOG_REG_EQN (gobj);
 
-	gui = go_libglade_new ("gog-reg-eqn-prefs.glade", "reg-eqn-prefs", GETTEXT_PACKAGE, cc);
+	gui = go_glade_new ("gog-reg-eqn-prefs.glade", "reg-eqn-prefs", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
-	gog_editor_add_page (editor, 
+	go_editor_add_page (editor, 
 			     glade_xml_get_widget (gui, "reg-eqn-prefs"),
 			     _("Details"));
 
@@ -421,13 +420,13 @@ gog_reg_eqn_class_init (GogObjectClass *gog_klass)
 			_("Show equation"),
 			_("Show the equation on the graph"),
 			TRUE, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, REG_EQN_SHOW_R2,
 		g_param_spec_boolean ("show-r2", 
 			_("Show coefficient"),
 			_("Show the correlation coefficient on the graph"),
 			TRUE, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 }
 
 static void
@@ -439,16 +438,16 @@ gog_reg_eqn_init (GogRegEqn *reg_eqn)
 
 GSF_CLASS (GogRegEqn, gog_reg_eqn,
 	   gog_reg_eqn_class_init, gog_reg_eqn_init,
-	   GOG_TEXT_TYPE)
+	   GOG_TYPE_TEXT)
 
 /************************************************************************/
 
 typedef GogOutlinedView		GogTextView;
 typedef GogOutlinedViewClass	GogTextViewClass;
 
-#define GOG_LABEL_VIEW_TYPE	(gog_label_view_get_type ())
-#define GOG_LABEL_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LABEL_VIEW_TYPE, GogLabelView))
-#define IS_GOG_LABEL_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_LABEL_VIEW_TYPE))
+#define GOG_TYPE_LABEL_VIEW	(gog_label_view_get_type ())
+#define GOG_LABEL_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_LABEL_VIEW, GogLabelView))
+#define GOG_IS_LABEL_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_LABEL_VIEW))
 
 static GogViewClass *text_view_parent_klass;
 
@@ -478,14 +477,14 @@ gog_text_view_render (GogView *view, GogViewAllocation const *bbox)
 {
 	GogText *text = GOG_TEXT (view->model);
 	GogOutlinedObject *goo = GOG_OUTLINED_OBJECT (text);
-	GogStyle *style = text->base.base.style;
+	GOStyle *style = text->base.base.style;
 	char *str = gog_text_get_str (text);
 
 	gog_renderer_push_style (view->renderer, style);
 	if (str != NULL) {
 		double outline = gog_renderer_line_size (view->renderer, 
 							 goo->base.style->outline.width);
-		if (style->fill.type != GOG_FILL_STYLE_NONE || outline > 0.) {
+		if (style->fill.type != GO_STYLE_FILL_NONE || outline > 0.) {
 			GogViewAllocation rect;
 			GOGeometryAABR aabr;
 			double pad_x = gog_renderer_pt2r_x (view->renderer, goo->padding_pts);
@@ -516,4 +515,4 @@ gog_text_view_class_init (GogTextViewClass *gview_klass)
 
 GSF_CLASS (GogTextView, gog_text_view,
 	   gog_text_view_class_init, NULL,
-	   GOG_OUTLINED_VIEW_TYPE)
+	   GOG_TYPE_OUTLINED_VIEW)
