@@ -20,11 +20,10 @@
 
 #include <goffice-config.h>
 #include "go-graph-widget.h"
-#include <gtk/gtklayout.h>
 #include <goffice/graph/gog-graph.h>
 #include <goffice/graph/gog-object.h>
 #include <goffice/graph/gog-renderer.h>
-#include <goffice/utils/go-math.h>
+#include <goffice/math/go-math.h>
 
 #include <gsf/gsf-impl-utils.h>
 
@@ -107,7 +106,7 @@ update_image_rect (GOGraphWidget *gw,
 	gw->xoffset = MAX (0, (int) (allocation.width - gw->width) / 2);
 
 	gog_graph_set_size (gw->graph, gw->width * 72. / gw->hres, gw->height * 72. / gw->vres);
-	gog_renderer_update (gw->renderer, gw->width, gw->height, 1.0);
+	gog_renderer_update (gw->renderer, gw->width, gw->height);
 }
 
 
@@ -130,33 +129,23 @@ static gboolean
 go_graph_widget_expose_event (GtkWidget *widget, GdkEventExpose *event)
 {
 	GOGraphWidget *w = GO_GRAPH_WIDGET (widget);
-	GdkPixbuf *pixbuf;
-	GdkRectangle display_rect, draw_rect;
-	GdkRegion *draw_region;
+	GdkDrawable *drawable = GTK_LAYOUT (widget)->bin_window;
+	cairo_t *cairo;
+	cairo_surface_t *surface;
 
 	if (event->window != GTK_LAYOUT (widget)->bin_window)
 		return FALSE;
 
-	pixbuf = gog_renderer_get_pixbuf (w->renderer);
-	display_rect.x = w->xoffset;
-	display_rect.y = w->yoffset;
-	display_rect.width  = w->width;
-	display_rect.height = w->height;
-	draw_region = gdk_region_rectangle (&display_rect);
-	gdk_region_intersect (draw_region, event->region);
-	if (!gdk_region_empty (draw_region)) {
-		gdk_region_get_clipbox (draw_region, &draw_rect);
-		gdk_draw_pixbuf (GTK_LAYOUT (widget)->bin_window, NULL, pixbuf,
-			/* pixbuf 0, 0 is at pix_rect.x, pix_rect.y */
-			     draw_rect.x - display_rect.x,
-			     draw_rect.y - display_rect.y,
-			     draw_rect.x,
-			     draw_rect.y,
-			     draw_rect.width,
-			     draw_rect.height,
-			     GDK_RGB_DITHER_NORMAL, 0, 0);
+	surface = gog_renderer_get_cairo_surface (w->renderer);
+	if (surface != NULL) {
+		cairo = gdk_cairo_create (drawable);
+		cairo_rectangle (cairo, w->xoffset, w->yoffset, w->width, w->height);
+		cairo_clip (cairo);
+		cairo_set_source_surface (cairo, surface, w->xoffset, w->yoffset);
+		cairo_paint (cairo);
+		cairo_destroy (cairo);
 	}
-	gdk_region_destroy (draw_region);
+
 	return FALSE;
 }
 
@@ -280,7 +269,7 @@ go_graph_widget_set_property (GObject *obj, guint param_id,
 		break;
 	case GRAPH_WIDGET_PROP_GRAPH :
 		w->graph = (GogGraph *) g_value_dup_object (value);
-		w->renderer = gog_renderer_new_for_pixbuf (w->graph);
+		w->renderer = gog_renderer_new (w->graph);
 		g_signal_connect_swapped (w->renderer, "request_update",
 			G_CALLBACK (go_graph_widget_request_update), w);
 		break;
@@ -372,6 +361,10 @@ go_graph_widget_init (GOGraphWidget *w)
 
 /**
  * go_graph_widget_set_size_mode :
+ * @widget : #GOGraphWidget
+ * @size_mode : #GOGraphWidgetSizeMode
+ * @width : in pixels
+ * @height : in pixels
  *
  * Sets the size mode of the #GOGraphWidget.
  * It is used to determine the size and position of the drawn
@@ -399,14 +392,14 @@ go_graph_widget_init (GOGraphWidget *w)
  * GO_GRAPH_WIDGET_SIZE_MODE_FIT_FIXED_SIZE, no aspect ratio set.
  * The graph will occupy the area specified by width/height,
  * its aspect ratio will be determined by height/width.
- */
+ **/
 void
 go_graph_widget_set_size_mode (GOGraphWidget         *widget,
 			       GOGraphWidgetSizeMode  size_mode,
 			       int                    width,
 			       int                    height)
 {
-	g_return_if_fail (IS_GO_GRAPH_WIDGET (widget));
+	g_return_if_fail (GO_IS_GRAPH_WIDGET (widget));
 	g_return_if_fail (size_mode >= GO_GRAPH_WIDGET_SIZE_MODE_FIT &&
 			  size_mode <= GO_GRAPH_WIDGET_SIZE_MODE_FIXED_SIZE);
 	g_return_if_fail (!(width >= 0 && height < 0));
@@ -423,11 +416,13 @@ go_graph_widget_set_size_mode (GOGraphWidget         *widget,
 
 /**
  * go_graph_widget_new :
+ * @graph : #GogGraph
  * 
  * Creates a new #GOGraphWidget with an embedded #GogGraph.
  * If graph is NULL, the graph will be auto-created, and a
  * #GogChart will be added graph.
- * Returns the newly created #GOGraphWidget.
+ *
+ * Returns: the newly created #GOGraphWidget.
  **/
 GtkWidget *
 go_graph_widget_new (GogGraph *graph)
@@ -438,11 +433,11 @@ go_graph_widget_new (GogGraph *graph)
 	if (graph == NULL) {
 		self_owned = TRUE;
 
-		graph = (GogGraph *) g_object_new (GOG_GRAPH_TYPE, NULL);
+		graph = (GogGraph *) g_object_new (GOG_TYPE_GRAPH, NULL);
 		gog_object_add_by_name (GOG_OBJECT (graph), "Chart", NULL);
 	}
 
-	ret = GTK_WIDGET (g_object_new (GO_GRAPH_WIDGET_TYPE, "graph", graph, NULL));
+	ret = GTK_WIDGET (g_object_new (GO_TYPE_GRAPH_WIDGET, "graph", graph, NULL));
 	go_graph_widget_set_size_mode (GO_GRAPH_WIDGET (ret), GO_GRAPH_WIDGET_SIZE_MODE_FIT, -1, -1);
 
 	if (self_owned)
@@ -459,12 +454,12 @@ GSF_CLASS (GOGraphWidget, go_graph_widget,
  * go_graph_widget_get_graph :
  * @widget : #GOGraphWidget
  * 
- * Returns the #GogGraph embedded in the widget.
+ * Returns: the #GogGraph embedded in the widget.
  **/
 GogGraph *
 go_graph_widget_get_graph (GOGraphWidget *widget)
 {
-	g_return_val_if_fail (IS_GO_GRAPH_WIDGET (widget), NULL);
+	g_return_val_if_fail (GO_IS_GRAPH_WIDGET (widget), NULL);
 	return widget->graph;
 }
 
@@ -472,12 +467,12 @@ go_graph_widget_get_graph (GOGraphWidget *widget)
  * go_graph_widget_get_chart :
  * @widget : #GOGraphWidget
  * 
- * Returns the #GogChart created by go_graph_widget_new().
+ * Returns: the #GogChart created by go_graph_widget_new().
  **/
 GogChart *
 go_graph_widget_get_chart (GOGraphWidget *widget)
 {
-	g_return_val_if_fail (IS_GO_GRAPH_WIDGET (widget), NULL);
+	g_return_val_if_fail (GO_IS_GRAPH_WIDGET (widget), NULL);
 	return (GogChart *) gog_object_get_child_by_name (
 						GOG_OBJECT (widget->graph), "Chart");
 }
